#! /usr/bin/python
## netconf - A switch mail tool
## Copyright (C) 2002 - 2010 Red Hat, Inc.
## Copyright (C) 2002 - 2010 Than Ngo <than@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import sys

SWITCHMAILDIR = '/usr/share/system-switch-mail/'

if not "/usr/lib/rhs/python" in sys.path:
    sys.path.append("/usr/lib/rhs/python")

if not SWITCHMAILDIR in sys.path:
    sys.path.append(SWITCHMAILDIR)

import signal
import os
import os.path
import string
import gettext
from functions import *


##
## I18N
##
gettext.bindtextdomain(PROGNAME, '/usr/share/locale')
gettext.textdomain(PROGNAME)
try:
    gettext.install(PROGNAME, '/usr/share/locale', 1)
except IOError:
    import __builtin__
    __builtin__.__dict__['_'] = unicode    

import gtk
import gtk.glade

class mainDialog:
    def __init__(self):
        pass

    def main(self):
        glade_file = 'switchmail.glade'

        if not os.path.isfile(glade_file):
            glade_file = GLADEPATH + glade_file
        if not os.path.isfile(glade_file):
            glade_file = SWITCHMAILDIR + glade_file

        self.xml = gtk.glade.XML(glade_file, None, domain=PROGNAME)

        self.xml.signal_autoconnect(
            {
            'on_cancelB_clicked' : self.on_cancelB_clicked,
            'on_okB_clicked' : self.on_okB_clicked,
            })

        self.dialog = self.xml.get_widget('window')
        self.okB = self.xml.get_widget('okB')
        self.sendmail_widget = self.xml.get_widget('sendmailRB')
        self.sendmail_widget.connect("toggled", self.changed)
        self.postfix_widget = self.xml.get_widget('postfixRB')
        self.postfix_widget.connect("toggled", self.changed)
        self.exim_widget = self.xml.get_widget('eximRB')
        self.exim_widget.connect("toggled", self.changed)
        self.ssmtp_widget = self.xml.get_widget('ssmtpRB')
        self.ssmtp_widget.connect("toggled", self.changed)
        self.esmtp_widget = self.xml.get_widget('esmtpRB')
        self.esmtp_widget.connect("toggled", self.changed)
        
        self.dialog.connect('delete-event', self.on_Dialog_delete_event)
        self.dialog.connect('hide', gtk.main_quit)
        self.load_icon('switchmail-mini.xpm', self.dialog)
        self.xml.get_widget('mailPixmap').set_from_file(SWITCHMAILDIR+'pixmaps/switchmail.png')

        self.hydrate()
        self.okB.set_sensitive(False)
        gtk.main()
        
    def changed(self, *args):
        self.okB.set_sensitive(True)

    def on_Dialog_delete_event(self, *args):
        gtk.main_quit()

    def on_cancelB_clicked(self, button):
        gtk.main_quit()

    def on_okB_clicked(self, button):
        if self.sendmail_widget.get_active():
            switch(SENDMAIL)
        elif self.postfix_widget.get_active():
            switch(POSTFIX)
        elif self.exim_widget.get_active():
            switch(EXIM)
        elif self.ssmtp_widget.get_active():
            switch(SSMTP)
        elif self.esmtp_widget.get_active():
            switch(ESMTP)

        self.dialog.hide()
        self.infoDialog()
        gtk.main_quit()

    def hydrate(self):
        self.xml.get_widget('mailLabel').set_text(TEXT)
        self.xml.get_widget('label').set_label('<span weight="bold">%s</span>' % _('Available Mail Transport Agent'))
        mta_list = get_mta()

        if len(mta_list) == 0:
            self.warningDialog()
            sys.exit(1)

        # show mta checkbox
        for mta in mta_list:
            if mta == 'Sendmail':
                self.sendmail_widget.show()
            if mta == 'Postfix':
                self.postfix_widget.show()
            if mta == 'Exim':
                self.exim_widget.show()
            if mta == 'sSMTP':
                self.ssmtp_widget.show()
            if mta == 'ESMTP':
                self.esmtp_widget.show()

        # activate default mta
        mta = get_default_mta(mta_list)
        if mta == 'Sendmail':
            self.sendmail_widget.set_active(TRUE)
        elif mta == 'Postfix':
                self.postfix_widget.set_active(TRUE)
        elif mta == 'Exim':
            self.exim_widget.set_active(TRUE)
        elif mta == 'sSMTP':
            self.ssmtp_widget.set_active(TRUE)
        elif mta == 'ESMTP':
            self.esmtp_widget.set_active(TRUE)

    def infoDialog(self):
        dlg = gtk.MessageDialog(self.dialog,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,                                
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                INFO_TEXT1)
        
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()

    def warningDialog(self):
        dlg = gtk.MessageDialog(self.dialog,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                WARNING_TEXT)
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()

    def get_pixbuf(self, pixmap_file):
        fn = pixmap_file
        if not os.path.exists(pixmap_file):
            pixmap_file = "pixmaps/" + fn
            if not os.path.exists(pixmap_file):
                pixmap_file = "../pixmaps/" + fn
                if not os.path.exists(pixmap_file):
                    pixmap_file = SWITCHMAILDIR + fn
                    if not os.path.exists(pixmap_file):
                        pixmap_file = SWITCHMAILDIR + "pixmaps/" + fn
                        if not os.path.exists(pixmap_file):
                            return None, None

        pixbuf = gtk.gdk.pixbuf_new_from_file(pixmap_file)

        return pixbuf

    def get_icon(self, pixmap_file, dialog):
        pixbuf = self.get_pixbuf(pixmap_file)
    
        pix, mask = pixbuf.render_pixmap_and_mask()
    
        return pix, mask


    def load_icon(self, pixmap_file, dialog):
        if not dialog: return
        
        pixbuf = self.get_pixbuf(pixmap_file)
        if not pixbuf: return
     
        if dialog: dialog.set_icon(pixbuf)

    def rootWarning(self, errMsg):
        dlg = gtk.MessageDialog(None,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                errMsg)
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()
        
# make ctrl-C work
if __name__ == '__main__':
    signal.signal (signal.SIGINT, signal.SIG_DFL)
    dlg = mainDialog().main()
    
    sys.exit(0)
